==> jc-1.4.0.tar.gz: gnu/java/locale/LocaleInformation__5fen__5fMH.h <==
// public class gnu.java.locale.LocaleInformation_en_MH

// class file dependencies
// @dep_class 3408016a2349508e gnu_java_locale_LocaleInformation__5fen__5fMH
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 33ddaf617676c508 java_util_ListResourceBundle
// @dep_class b0f2ff51263ebf06 java_util_ResourceBundle

// header file dependencies
// @dep_header java_util_ListResourceBundle

#include "java/util/ListResourceBundle.h"

#ifndef _JC_gnu_java_locale_LocaleInformation__5fen__5fMH_H_
#define _JC_gnu_java_locale_LocaleInformation__5fen__5fMH_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$sub_refs	_jc_gnu_java_locale_LocaleInformation__5fen__5fMH$sub_refs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$sub_nonrefs	_jc_gnu_java_locale_LocaleInformation__5fen__5fMH$sub_nonrefs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$refs	_jc_gnu_java_locale_LocaleInformation__5fen__5fMH$refs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$nonrefs	_jc_gnu_java_locale_LocaleInformation__5fen__5fMH$nonrefs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$object	_jc_gnu_java_locale_LocaleInformation__5fen__5fMH$object;

typedef struct _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$fields_struct	_jc_gnu_java_locale_LocaleInformation__5fen__5fMH$fields_struct;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$vmethods	_jc_gnu_java_locale_LocaleInformation__5fen__5fMH$vmethods;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$vtable	_jc_gnu_java_locale_LocaleInformation__5fen__5fMH$vtable;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$vtype	_jc_gnu_java_locale_LocaleInformation__5fen__5fMH$vtype;

// Class fields structure
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$fields_struct {
	_jc_object_array	*contents;
};
extern _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$fields_struct _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$class_fields;

// Constructors
extern void _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$object *);

// Virtual methods
extern _jc_object_array *_jc_gnu_java_locale_LocaleInformation__5fen__5fMH$method$getContents$77295dd4f2da9d10(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$method_info$getContents$77295dd4f2da9d10;

// Static methods
extern void _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$vmethods {
	_jc_object_array	*(*getContents$77295dd4f2da9d10)(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$object *);
};

// Vtable
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_ResourceBundle$vmethods	java_util_ResourceBundle;
	_jc_java_util_ListResourceBundle$vmethods	java_util_ListResourceBundle;
	_jc_gnu_java_locale_LocaleInformation__5fen__5fMH$vmethods	gnu_java_locale_LocaleInformation__5fen__5fMH;
};

// Vtype
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$vtype {
	_jc_type			type;
	_jc_gnu_java_locale_LocaleInformation__5fen__5fMH$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$refs {
    _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$sub_refs	gnu_java_locale_LocaleInformation__5fen__5fMH;
    _jc_java_util_ListResourceBundle$sub_refs	java_util_ListResourceBundle;
    _jc_java_util_ResourceBundle$sub_refs	java_util_ResourceBundle;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_ResourceBundle$sub_nonrefs	java_util_ResourceBundle;
    _jc_java_util_ListResourceBundle$sub_nonrefs	java_util_ListResourceBundle;
    _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$sub_nonrefs	gnu_java_locale_LocaleInformation__5fen__5fMH;
};

// Object instance structure
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$object {
	_jc_gnu_java_locale_LocaleInformation__5fen__5fMH$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_locale_LocaleInformation__5fen__5fMH$vtype	*vtype;
	_jc_gnu_java_locale_LocaleInformation__5fen__5fMH$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$vtype _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_locale_LocaleInformation__5fen__5fMH, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$class_object;

#endif	/* _JC_gnu_java_locale_LocaleInformation__5fen__5fMH_H_ */

==> jc-1.4.5.tar.gz: gnu/java/locale/LocaleInformation__5fen__5fMH.h <==
// public class gnu.java.locale.LocaleInformation_en_MH

// class file dependencies
// @dep_class 3408016a2349508e gnu_java_locale_LocaleInformation__5fen__5fMH
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 33ddaf617676c508 java_util_ListResourceBundle
// @dep_class b0f2ff51263ebf06 java_util_ResourceBundle

// header file dependencies
// @dep_header java_util_ListResourceBundle

#include "java/util/ListResourceBundle.h"

#ifndef _JC_gnu_java_locale_LocaleInformation__5fen__5fMH_H_
#define _JC_gnu_java_locale_LocaleInformation__5fen__5fMH_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$sub_refs	_jc_gnu_java_locale_LocaleInformation__5fen__5fMH$sub_refs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$sub_nonrefs	_jc_gnu_java_locale_LocaleInformation__5fen__5fMH$sub_nonrefs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$refs	_jc_gnu_java_locale_LocaleInformation__5fen__5fMH$refs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$nonrefs	_jc_gnu_java_locale_LocaleInformation__5fen__5fMH$nonrefs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$object	_jc_gnu_java_locale_LocaleInformation__5fen__5fMH$object;

typedef struct _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$fields_struct	_jc_gnu_java_locale_LocaleInformation__5fen__5fMH$fields_struct;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$vmethods	_jc_gnu_java_locale_LocaleInformation__5fen__5fMH$vmethods;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$vtable	_jc_gnu_java_locale_LocaleInformation__5fen__5fMH$vtable;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$vtype	_jc_gnu_java_locale_LocaleInformation__5fen__5fMH$vtype;

// Class fields structure
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$fields_struct {
	_jc_object_array	*contents;
};
extern _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$fields_struct _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$class_fields;

// Constructors
extern void _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$object *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_object_array *_jc_gnu_java_locale_LocaleInformation__5fen__5fMH$method$getContents$77295dd4f2da9d10(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$method_info$getContents$77295dd4f2da9d10;

// Static methods
extern void _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$vmethods {
	_jc_object_array	*(*getContents$77295dd4f2da9d10)(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_ResourceBundle$vmethods	java_util_ResourceBundle;
	_jc_java_util_ListResourceBundle$vmethods	java_util_ListResourceBundle;
	_jc_gnu_java_locale_LocaleInformation__5fen__5fMH$vmethods	gnu_java_locale_LocaleInformation__5fen__5fMH;
};

// Vtype
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$vtype {
	_jc_type			type;
	_jc_gnu_java_locale_LocaleInformation__5fen__5fMH$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$refs {
    _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$sub_refs	gnu_java_locale_LocaleInformation__5fen__5fMH;
    _jc_java_util_ListResourceBundle$sub_refs	java_util_ListResourceBundle;
    _jc_java_util_ResourceBundle$sub_refs	java_util_ResourceBundle;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_ResourceBundle$sub_nonrefs	java_util_ResourceBundle;
    _jc_java_util_ListResourceBundle$sub_nonrefs	java_util_ListResourceBundle;
    _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$sub_nonrefs	gnu_java_locale_LocaleInformation__5fen__5fMH;
};

// Object instance structure
struct _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$object {
	_jc_gnu_java_locale_LocaleInformation__5fen__5fMH$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_locale_LocaleInformation__5fen__5fMH$vtype	*vtype;
	_jc_gnu_java_locale_LocaleInformation__5fen__5fMH$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$vtype _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_locale_LocaleInformation__5fen__5fMH, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_locale_LocaleInformation__5fen__5fMH$class_object;

#endif	/* _JC_gnu_java_locale_LocaleInformation__5fen__5fMH_H_ */
